@@ -14,7 +14,7 @@ import tempfile
 
 from os import path
 
-VERSION = '0.3.0'
+VERSION = '0.3.1'
 
 class Dotlink(object):
     """Copy or symlink dotfiles from a profile repository to a new location,
@@ -209,6 +209,9 @@ class Dotlink(object):
 
     def deploy_remote(self, dotfiles):
         """Deploy dotfiles to a remote server."""
+        tempfile_path = None
+        tempdir_path = None
+
         try:
             tempdir_path = tempfile.mkdtemp()
             self.log.debug('Deploying to temp dir %s', tempdir_path)
@@ -225,16 +228,21 @@ class Dotlink(object):
             self.log.debug('Uploading tarball to %s', upload_path)
             self.scp(tempfile_path, upload_path)
 
-            ssh_command = "'mkdir -p {0} && tar xf _profile_upload.tgz -C {0} "\
-                          "&& rm -f _profile_upload.tgz'".format(self.args.path)
+            if self.args.path:
+                ssh_command = "'mkdir -p {0} && "\
+                              "tar xf _profile_upload.tgz -C {0}; "\
+                              "rm -f _profile_upload.tgz'".format(self.args.path)
+            else:
+                ssh_command = "tar xf _profile_upload.tgz; "\
+                              "rm -f _profile_upload.tgz"
             self.log.debug('Using ssh to unpack tarball and clean up')
             self.ssh(ssh_command)
 
         finally:
-            if path.isdir(tempdir_path):
+            if tempdir_path and path.isdir(tempdir_path):
                 self.log.debug('Removing temp dir %s', tempdir_path)
                 shutil.rmtree(tempdir_path)
-            if path.isfile(tempfile_path):
+            if tempfile_path and path.isfile(tempfile_path):
                 self.log.debug('Removing temp file %s', tempfile_path)
                 os.unlink(tempfile_path)
 
@@ -262,10 +270,12 @@ class Dotlink(object):
 
             if self.args.copy:
                 if path.isdir(source_path):
-                    self.log.debug('Copying file %s to %s', source_path, target_path)
+                    self.log.debug('Copying file %s to %s',
+                                   source_path, target_path)
                     shutil.copytree(source_path, target_path)
                 else:
-                    self.log.debug('Copying dir %s to %s', source_path, target_path)
+                    self.log.debug('Copying dir %s to %s',
+                                   source_path, target_path)
                     shutil.copy(source_path, target_path)
 
             else:
